<?php
/*
Plugin Name: WP-iCal
Version: 2006-04-12
Plugin URI: http://www.garrickvanburen.com/wpical/
Description: WP-iCal creates iCal subscribable calendars (.ics files) from your posts. If you this plugin works for you, <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=garrick%40podcastmn%2ecom&item_name=WP%2diCal%20Plugin&amount=15%2e00&no_shipping=0&no_note=1&tax=0&currency_code=USD&bn=PP%2dDonationsBF&charset=UTF%2d8">support its development</a>.
Author: Garrick Van Buren
Author URI: http://garrickvanburen.com/
*/

if(is_plugin_page()) { 
    wp_ical_config(); 
} else {
    if (!(get_option('wp_ical_version'))) {	add_option('wp_ical_version'); }
    add_action('wp_head', 'wp_ical_gmap_header');           // DISPLAYS THE GOOGLE MAP JAVASCRIPT
    add_action('admin_head', 'wp_ical_add_options_page');
    add_action('simple_edit_form','wp_ical_form', 8);       // DISPLAYS THE LOCATION, START, DURATION, IN THE SIMPLE FORM
    add_action('edit_form_advanced','wp_ical_form', 8);       // DISPLAYS THE LOCATION, START, DURATION, IN THE ADVANCED FORM
    add_action('save_post','wp_ical_save_post', 8);              // UPDATES THE CALENDAR FILE WHEN A NEW POST IS ADDED
    add_action('edit_post','wp_ical_save_post', 8);              // UPDATES THE CALENDAR FILE WHEN A POST IS UPDATED 

/* Add WP-iCal Tab to Options Menu */
function wp_ical_add_options_page() {
	if (function_exists('add_options_page')) {  add_options_page('WP-iCal Configuration', 'WP-iCal', 5, basename(__FILE__));  }
}

/* Add Google Maps Javascript to Header */
function wp_ical_gmap_header() {
    if (get_option('iCalGoogleMapKey')) {?>
    <script src="http://maps.google.com/maps?file=api&amp;v=2&amp;key=<?php echo get_option('iCalGoogleMapKey');?>" type="text/javascript"></script>
<?php } }

function wp_ical_save_post($post_ID) {
    if (!$post_ID) { $post_ID = $_POST['post_ID']; }
    if ($_POST['location']) {
        $location = $_POST['location'];
        $starttime = date("Y-m-d H:i:s", mktime($_POST['sh'], $_POST['sn'], 0, $_POST['sm'], $_POST['sj'], $_POST['sa']));
        $endtime = date("Y-m-d H:i:s", mktime($_POST['eh'], $_POST['en'], 0, $_POST['em'], $_POST['ej'], $_POST['ea']));
        $alldayevent = $_POST['ad'];
        wp_ical_writemeta($post_ID, $location, $starttime, $endtime, $alldayevent);
    }
}

function wp_ical_strip_content($post) {
    $content = strip_tags($post);
    $content = str_replace("\n", " ", $content);
    $content = str_replace("\r", " ", $content);
    $content = str_replace("\0", " ", $content);
    return $content;
}

function wp_ical_process() {
    if(isset($_POST['iCalGoogleMapKey'])) { update_option('iCalGoogleMapKey', $_POST['iCalGoogleMapKey']); }
    if(isset($_POST['iCalGoogleMapZoom'])) { update_option('iCalGoogleMapZoom', $_POST['iCalGoogleMapZoom']); }
    if(isset($_POST['iCalGoogleMapWidth'])) { update_option('iCalGoogleMapWidth', $_POST['iCalGoogleMapWidth']); }
    if(isset($_POST['iCalGoogleMapHeight'])) { update_option('iCalGoogleMapHeight', $_POST['iCalGoogleMapHeight']); }
    if(isset($_POST['iCalUpcomingKey'])) { update_option('iCalUpcomingKey', $_POST['iCalUpcomingKey']); }
    if(isset($_POST['iCalTimezone'])) { update_option('iCalTimezone', $_POST['iCalTimezone']); }
    $location = get_option('siteurl') . '/wp-admin/admin.php?page=wp-ical-plugin.php';
	header('Location: '.$location);
}

if(isset($_POST['submitted'])) { wp_ical_process(); }

function wp_ical_print_map($post) { 
    $coord = explode("/", wp_ical_get($post, 'geocode'));
    if ($coord) {
?>
    <div id="map-<?php echo $post; ?>" style="width: <?php echo get_option('iCalGoogleMapWidth') ;?>px; height: <?php echo get_option('iCalGoogleMapHeight') ;?>px"></div>
    
    <script type="text/javascript">
    if (GBrowserIsCompatible()) {
        var map = new GMap(document.getElementById("map-<?php echo $post; ?>"));
        var point = new GPoint(<?php echo $coord[1]; ?>, <?php echo $coord[0]; ?>);
        map.addControl(new GSmallMapControl());
        map.centerAndZoom(point, <?php echo get_option('iCalGoogleMapZoom'); ?>);
        var marker = new GMarker(point); 
        map.addControl(new GSmallMapControl());
        map.addOverlay(marker);
        
        GEvent.addListener(map, "click", function(marker, point) {
            function tohere() { 
                marker.openInfoWindowHtml('<div style="white-space:nowrap;">'+to_htmls+'<\/div>'); 
            }
        
            function fromhere() { 
                marker.openInfoWindowHtml('<div style="white-space:nowrap;">'+from_htmls+'<\/div>'); 
            }
            
            var text = '<a href="javascript:tohere()">To here<\/a> - ' +  '<a href="javascript:fromhere()">From here<\/a>';
        
             marker.openInfoWindowHtml('<div style="white-space:nowrap;">' + text + '<\/div>');
        
            var to_htmls = 'Directions: <b>to here<\/b> - ' +
                    '<a href="javascript:fromhere()">from here<\/a><br /><br />' +
                    'Start address:<form action="http://maps.google.com/maps" method="get" target="_blank">' +
                     '<input type="text" SIZE=24 MAXLENGTH=72 name="saddr" id="saddr" value="" /><br>' +
                     '<input value="Get Directions" TYPE="SUBMIT">' +
                     '<input type="hidden" name="daddr" value="' +
                     point.y + ',' + point.x + "(" + name + ")" + '"/>';

            var from_htmls = 'Directions: <a href="javascript:tohere()">to here<\/a> - ' +
                     '<b>from here<\/b><br /><br />' +
                     'End address:<form action="http://maps.google.com/maps" method="get"" target="_blank">' +
                     '<input type="text" SIZE=24 MAXLENGTH=72 name="daddr" id="daddr" value="" /><br>' +
                 '<input value="Get Directions" TYPE="SUBMIT">' +
                  '<input type="hidden" name="saddr" value="' +
                   point.y + ',' + point.x + "(" + name + ")" + '"/>';
        });

    }
</script>
<?php } }


function wp_ical_form() { ?>
	<div id="advancedstuff" class="dbx-group" >
	<div class="dbx-box-wrapper">
	<fieldset class="dbx-box">
	<div class="dbx-handle-wrapper">
	<h3 class="dbx-handle">Calendar Event Details</h3>
	</div>
	<div class="dbx-content-wrapper">
	<div class="dbx-content">
			<?php wp_ical_form_location(); ?>
			<?php wp_ical_form_starttime(); ?>
			<?php wp_ical_form_endtime(); ?>
	</div>
	</div>
	</fieldset>
	</div>
	</div
	
<?php } 

function wp_ical_get($post, $detail) {
    global $wpdb, $tablepostmeta;
    $detail = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE post_id = '$post' AND meta_key = '$detail'");
    return $detail;
}

function wp_ical_form_starttime() {
	global $wpdb, $month, $postdata, $tablepostmeta;
    
    if ($_GET['action'] == 'edit') {
        $edit = 1;
        $post_id = $_GET['post'];
        $starttime = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'starttime' AND post_id = '$post_id'");
    
        $ad = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'alldayevent' AND post_id = '$post_id'"); 
        if ($ad == "on") { $ad = "checked"; }
    } ?> 
    <legend>Start Time</legend><br />
    <?php
    $time_adj = time() + (get_settings('gmt_offset') * 3600);
	$sj = ($edit) ? mysql2date('d', $starttime) : gmdate('d', $time_adj);
	$sm = ($edit) ? mysql2date('m', $starttime) : gmdate('m', $time_adj);
	$sa = ($edit) ? mysql2date('Y', $starttime) : gmdate('Y', $time_adj);
	$sh = ($edit) ? mysql2date('H', $starttime) : gmdate('H', $time_adj);
	$sn = ($edit) ? mysql2date('i', $starttime) : gmdate('i', $time_adj);

	echo "<select name=\"sm\">\n";
	for ($i=1; $i < 13; $i=$i+1) {
		echo "\t\t\t<option value=\"$i\"";
		if ($i == $sm)
		echo " selected='selected'";
		if ($i < 10) {
			$ii = "0".$i;
		} else {
			$ii = "$i";
		}
		echo ">".$month["$ii"]."</option>\n";
	} ?>
    </select>
    <input type="text" name="sj" value="<?php echo $sj; ?>" size="2" maxlength="2" />
    <input type="text" name="sa" value="<?php echo $sa; ?>" size="4" maxlength="5" /> @ 
    <input type="text" name="sh" value="<?php echo $sh; ?>" size="2" maxlength="2" /> : 
    <input type="text" name="sn" value="<?php echo $sn; ?>" size="2" maxlength="2" /> <input type="checkbox" name="ad" <?php echo $ad; ?> /> All Day Event<br />

<?php } 

function wp_ical_form_endtime() {
	global $wpdb, $month, $postdata, $tablepostmeta;
    
    if ($_GET['action'] == 'edit') {
        $edit = 1;
        $post_id = $_GET['post'];
        $endtime = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'endtime' AND post_id = '$post_id'");
    } ?>
    <legend>End Time</legend><br />
	<?php 
	$time_adj = time() + (get_settings('gmt_offset') * 3600);

	$ej = ($edit) ? mysql2date('d', $endtime) : gmdate('d', $time_adj);
	$em = ($edit) ? mysql2date('m', $endtime) : gmdate('m', $time_adj);
	$ea = ($edit) ? mysql2date('Y', $endtime) : gmdate('Y', $time_adj);
	$eh = ($edit) ? mysql2date('H', $endtime) : gmdate('H', $time_adj);
	$en = ($edit) ? mysql2date('i', $endtime) : gmdate('i', $time_adj);

	echo "<select name=\"em\">\n";
	for ($i=1; $i < 13; $i=$i+1) {
		echo "\t\t\t<option value=\"$i\"";
		if ($i == $em)
		echo " selected='selected'";
		if ($i < 10) {
			$ii = "0".$i;
		} else {
			$ii = "$i";
		}
		echo ">".$month["$ii"]."</option>\n";
	} ?>

    </select>
    <input type="text" name="ej" value="<?php echo $ej; ?>" size="2" maxlength="2" />
    <input type="text" name="ea" value="<?php echo $ea; ?>" size="4" maxlength="5" /> @ 
    <input type="text" name="eh" value="<?php echo $eh; ?>" size="2" maxlength="2" /> : 
    <input type="text" name="en" value="<?php echo $en; ?>" size="2" maxlength="2" /> <br />
<?php }

function wp_ical_form_location() {
	global $wpdb, $tablepostmeta;
    	
    if ($_GET['action'] == 'edit') {
        $post_id = $_GET['post'];
        $location = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'location' AND post_id = '$post_id'");
        $geocode = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'geocode' AND post_id = '$post_id'");
    } ?>
   
        <legend>Location</legend><br />
        <input type="text" name="location" value="<?php echo $location; ?>" size="35"><br />
<?php }

function wp_ical_writemeta($post_ID, $location, $starttime, $endtime, $alldayevent) {
    global $wpdb, $tablepostmeta;
    
    // LOCATION
    $result = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'location' AND post_id = '$post_ID'");  

    if ($result) {
        $result = $wpdb->query("UPDATE $tablepostmeta SET meta_value = '$location' WHERE post_id = '$post_ID' AND meta_key = 'location'");  
    } else {
        $result = $wpdb->query("INSERT INTO $tablepostmeta (post_id,meta_key,meta_value) VALUES ('$post_ID','location','$location')");   
    }
    
    // GEOPOSITION
    $geocode = wp_ical_get_geo($location);   
        if (geocode) {
        $result =  $wpdb->query("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'geocode' AND post_id = '$post_ID'"); 
    
        if ($result) {
            $result = $wpdb->query("UPDATE $tablepostmeta SET meta_value = '$geocode' WHERE post_id = '$post_ID' AND meta_key = 'geocode'");  
        } else {
            $result = $wpdb->query("INSERT INTO $tablepostmeta (post_id,meta_key,meta_value) VALUES ('$post_ID','geocode','$geocode')");   
        }
    }
    
    // START TIME
    $result = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'starttime' AND post_id = '$post_ID'");

    if ($result) {
        $result = $wpdb->query("UPDATE $tablepostmeta SET meta_value = '$starttime' WHERE post_id = '$post_ID' AND meta_key = 'starttime'");    
    } else {
        $result = $wpdb->query("INSERT INTO $tablepostmeta (post_id,meta_key,meta_value) VALUES ('$post_ID','starttime','$starttime')");
    }
    
    // END TIME
    $result = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'endtime' AND post_id = '$post_ID'");

    if ($result) {
        $result = $wpdb->query("UPDATE $tablepostmeta SET meta_value = '$endtime' WHERE post_id = '$post_ID' AND meta_key = 'endtime'");    
    } else {
        $result = $wpdb->query("INSERT INTO $tablepostmeta (post_id,meta_key,meta_value) VALUES ('$post_ID','endtime','$endtime')");
    }    

    // ALL DAY EVENT
    if (!$alldayevent) { $alldayevent = "off"; } else { $alldayevent = "on"; }

        $result = $wpdb->get_var("SELECT meta_value FROM $tablepostmeta WHERE meta_key = 'alldayevent' AND post_id = '$post_ID'");

        if ($result) {
            $result = $wpdb->query("UPDATE $tablepostmeta SET meta_value = '$alldayevent' WHERE post_id = '$post_ID' AND meta_key = 'alldayevent'");    
        } else {
            $result = $wpdb->query("INSERT INTO $tablepostmeta (post_id,meta_key,meta_value) VALUES ('$post_ID','alldayevent','$alldayevent')");
        }    
}

function wp_ical_get_geo($address) {
    $_url = 'http://api.local.yahoo.com/MapsService/V1/geocode?appid=garrickwpical&location=' . rawurlencode($address);
    $_result = false;
    if($_result = file_get_contents($_url)) {
        preg_match('!<Latitude>(.*)</Latitude><Longitude>(.*)</Longitude>!U', $_result, $_match);
        $_coords = $_match[1] . "/" . $_match[2];
    } else {
        $_coords = "";
    }
    return $_coords;       
}

function wp_ical_config() {
    $iCalGoogleMapKey = get_option('iCalGoogleMapKey');
    $iCalGoogleMapZoom = get_option('iCalGoogleMapZoom');
    $iCalGoogleMapWidth = get_option('iCalGoogleMapWidth');
    $iCalGoogleMapHeight = get_option('iCalGoogleMapHeight');
    $iCalUpcomingKey = get_option('iCalUpcomingKey');
    $iCalTimezone = get_option('iCalTimezone');
    
    $timezones = array("Africa/Addis_Ababa","Africa/Algiers","Africa/Asmera","Africa/Bangui","Africa/Blantyre","Africa/Brazzaville","Africa/Bujumbura","Africa/Cairo","Africa/Ceuta","Africa/Dar_es_Salaam","Africa/Djibouti","Africa/Douala","Africa/Gaborone","Africa/Harare","Africa/Johannesburg","Africa/Kampala","Africa/Khartoum","Africa/Kigali","Africa/Kinshasa","Africa/Lagos","Africa/Libreville","Africa/Luanda","Africa/Lubumbashi","Africa/Lusaka","Africa/Malabo","Africa/Maputo","Africa/Maseru","Africa/Mbabane","Africa/Mogadishu","Africa/Nairobi","Africa/Ndjamena","Africa/Niamey","Africa/Porto-Novo","Africa/Tripoli","Africa/Tunis","Africa/Windhoek","America/Adak","America/Anchorage","America/Anguilla","America/Antigua","America/Araguaina","America/Aruba","America/Asuncion","America/Atka","America/Barbados","America/Belem","America/Belize","America/Boa_Vista","America/Bogota","America/Boise","America/Buenos_Aires","America/Cambridge_Bay","America/Cancun","America/Caracas","America/Catamarca","America/Cayenne","America/Cayman","America/Chicago","America/Chihuahua","America/Cordoba","America/Costa_Rica","America/Cuiaba","America/Curacao","America/Dawson","America/Dawson_Creek","America/Denver","America/Detroit","America/Dominica","America/Edmonton","America/Eirunepe","America/El_Salvador","America/Ensenada","America/Fort_Wayne","America/Fortaleza","America/Glace_Bay","America/Godthab","America/Goose_Bay","America/Grand_Turk","America/Grenada","America/Guadeloupe","America/Guatemala","America/Guayaquil","America/Guyana","America/Halifax","America/Havana","America/Hermosillo","America/Indiana/Indianapolis","America/Indiana/Knox","America/Indiana/Marengo","America/Indiana/Vevay","America/Indianapolis","America/Inuvik","America/Iqaluit","America/Jamaica","America/Jujuy","America/Juneau","America/Kentucky/Louisville","America/Kentucky/Monticello","America/Knox_IN","America/La_Paz","America/Lima","America/Los_Angeles","America/Louisville","America/Maceio","America/Managua","America/Manaus","America/Martinique","America/Mazatlan","America/Mendoza","America/Menominee","America/Merida","America/Mexico_City","America/Miquelon","America/Monterrey","America/Montevideo","America/Montreal","America/Montserrat","America/Nassau","America/New_York","America/Nipigon","America/Nome","America/Noronha","America/Panama","America/Pangnirtung","America/Paramaribo","America/Phoenix","America/Port-au-Prince","America/Port_of_Spain","America/Porto_Acre","America/Porto_Velho","America/Puerto_Rico","America/Rainy_River","America/Rankin_Inlet","America/Recife","America/Regina","America/Rio_Branco","America/Rosario","America/Santiago","America/Santo_Domingo","America/Sao_Paulo","America/Scoresbysund","America/Shiprock","America/St_Johns","America/St_Kitts","America/St_Lucia","America/St_Thomas","America/St_Vincent","America/Swift_Current","America/Tegucigalpa","America/Thule","America/Thunder_Bay","America/Tijuana","America/Tortola","America/Vancouver","America/Virgin","America/Whitehorse","America/Winnipeg","America/Yakutat","America/Yellowknife","Antarctica/Casey","Antarctica/Davis","Antarctica/DumontDUrville","Antarctica/Mawson","Antarctica/McMurdo","Antarctica/Palmer","Antarctica/South_Pole","Antarctica/Syowa","Antarctica/Vostok","Arctic/Longyearbyen","Asia/Aden","Asia/Almaty","Asia/Amman","Asia/Anadyr","Asia/Aqtau","Asia/Aqtobe","Asia/Ashgabat","Asia/Ashkhabad","Asia/Baghdad","Asia/Bahrain","Asia/Baku","Asia/Bangkok","Asia/Beirut","Asia/Bishkek","Asia/Brunei","Asia/Calcutta","Asia/Chungking","Asia/Colombo","Asia/Dacca","Asia/Damascus","Asia/Dhaka","Asia/Dili","Asia/Dubai","Asia/Dushanbe","Asia/Gaza","Asia/Harbin","Asia/Hong_Kong","Asia/Hovd","Asia/Irkutsk","Asia/Istanbul","Asia/Jakarta","Asia/Jayapura","Asia/Jerusalem","Asia/Kabul","Asia/Kamchatka","Asia/Karachi","Asia/Kashgar","Asia/Katmandu","Asia/Krasnoyarsk","Asia/Kuala_Lumpur","Asia/Kuching","Asia/Kuwait","Asia/Macao","Asia/Magadan","Asia/Manila","Asia/Muscat","Asia/Nicosia","Asia/Novosibirsk","Asia/Omsk","Asia/Phnom_Penh","Asia/Pyongyang","Asia/Qatar","Asia/Rangoon","Asia/Riyadh","Asia/Riyadh87","Asia/Riyadh88","Asia/Riyadh89","Asia/Saigon","Asia/Samarkand","Asia/Seoul","Asia/Shanghai","Asia/Singapore","Asia/Taipei","Asia/Tashkent","Asia/Tbilisi","Asia/Tehran","Asia/Tel_Aviv","Asia/Thimbu","Asia/Thimphu","Asia/Tokyo","Asia/Ujung_Pandang","Asia/Ulaanbaatar","Asia/Ulan_Bator","Asia/Urumqi","Asia/Vientiane","Asia/Vladivostok","Asia/Yakutsk","Asia/Yekaterinburg","Asia/Yerevan","Atlantic/Azores","Atlantic/Bermuda","Atlantic/Canary","Atlantic/Cape_Verde","Atlantic/Faeroe","Atlantic/Jan_Mayen","Atlantic/Madeira","Atlantic/South_Georgia","Atlantic/Stanley","Australia/ACT","Australia/Adelaide","Australia/Brisbane","Australia/Broken_Hill","Australia/Canberra","Australia/Darwin","Australia/Hobart","Australia/LHI","Australia/Lindeman","Australia/Lord_Howe","Australia/Melbourne","Australia/NSW","Australia/North","Australia/Perth","Australia/Queensland","Australia/South","Australia/Sydney","Australia/Tasmania","Australia/Victoria","Australia/West","Australia/Yancowinna","Brazil/Acre","Brazil/DeNoronha","Brazil/East","Brazil/West","CET","CST6CDT","Canada/Atlantic","Canada/Central","Canada/East-Saskatchewan","Canada/Eastern","Canada/Mountain","Canada/Newfoundland","Canada/Pacific","Canada/Saskatchewan","Canada/Yukon","Chile/Continental","Chile/EasterIsland","Cuba","EET","EST","EST5EDT","Egypt","Eire","Etc/GMT+1","Etc/GMT+10","Etc/GMT+11","Etc/GMT+12","Etc/GMT+2","Etc/GMT+3","Etc/GMT+4","Etc/GMT+5","Etc/GMT+6","Etc/GMT+7","Etc/GMT+8","Etc/GMT+9","Etc/GMT-1","Etc/GMT-10","Etc/GMT-11","Etc/GMT-12","Etc/GMT-13","Etc/GMT-14","Etc/GMT-2","Etc/GMT-3","Etc/GMT-4","Etc/GMT-5","Etc/GMT-6","Etc/GMT-7","Etc/GMT-8","Etc/GMT-9","Europe/Amsterdam","Europe/Andorra","Europe/Athens","Europe/Belfast","Europe/Belgrade","Europe/Berlin","Europe/Bratislava","Europe/Brussels","Europe/Bucharest","Europe/Budapest","Europe/Chisinau","Europe/Copenhagen","Europe/Dublin","Europe/Gibraltar","Europe/Helsinki","Europe/Istanbul","Europe/Kaliningrad","Europe/Kiev","Europe/Lisbon","Europe/Ljubljana","Europe/London","Europe/Luxembourg","Europe/Madrid","Europe/Malta","Europe/Minsk","Europe/Monaco","Europe/Moscow","Europe/Nicosia","Europe/Oslo","Europe/Paris","Europe/Prague","Europe/Riga","Europe/Rome","Europe/Samara","Europe/San_Marino","Europe/Sarajevo","Europe/Simferopol","Europe/Skopje","Europe/Sofia","Europe/Stockholm","Europe/Tallinn","Europe/Tirane","Europe/Tiraspol","Europe/Uzhgorod","Europe/Vaduz","Europe/Vatican","Europe/Vienna","Europe/Vilnius","Europe/Warsaw","Europe/Zagreb","Europe/Zaporozhye","Europe/Zurich","GB","GB-Eire","GMT","HST","Hongkong","Indian/Antananarivo","Indian/Chagos","Indian/Christmas","Indian/Cocos","Indian/Comoro","Indian/Kerguelen","Indian/Mahe","Indian/Maldives","Indian/Mauritius","Indian/Mayotte","Indian/Reunion","Iran","Israel","Jamaica","Japan","Kwajalein","Libya","MET","MST","MST7MDT","Mexico/BajaNorte","Mexico/BajaSur","Mexico/General","Mideast/Riyadh87","Mideast/Riyadh88","Mideast/Riyadh89","NZ","NZ-CHAT","Navajo","PRC","PST8PDT","Pacific/Apia","Pacific/Auckland","Pacific/Chatham","Pacific/Easter","Pacific/Efate","Pacific/Enderbury","Pacific/Fakaofo","Pacific/Fiji","Pacific/Funafuti","Pacific/Galapagos","Pacific/Gambier","Pacific/Guadalcanal","Pacific/Guam","Pacific/Honolulu","Pacific/Johnston","Pacific/Kiritimati","Pacific/Kosrae","Pacific/Kwajalein","Pacific/Majuro","Pacific/Marquesas","Pacific/Midway","Pacific/Nauru","Pacific/Niue","Pacific/Norfolk","Pacific/Noumea","Pacific/Pago_Pago","Pacific/Palau","Pacific/Pitcairn","Pacific/Ponape","Pacific/Port_Moresby","Pacific/Rarotonga","Pacific/Saipan","Pacific/Samoa","Pacific/Tahiti","Pacific/Tarawa","Pacific/Tongatapu","Pacific/Truk","Pacific/Wake","Pacific/Wallis","Pacific/Yap","Poland","Portugal","ROC","ROK","Singapore","SystemV/AST4","SystemV/AST4ADT","SystemV/CST6","SystemV/CST6CDT","SystemV/EST5","SystemV/EST5EDT","SystemV/HST10","SystemV/MST7","SystemV/MST7MDT","SystemV/PST8","SystemV/PST8PDT","SystemV/YST9","SystemV/YST9YDT","Turkey","US/Alaska","US/Aleutian","US/Arizona","US/Central","US/East-Indiana","US/Eastern","US/Hawaii","US/Indiana-Starke","US/Michigan","US/Mountain","US/Pacific","US/Samoa","W-SU-SU","WETET"); ?>
<div class="wrap">
	<h2>Configure WP-iCal</h2>
    <form action="<?php echo $_SERVER['PHP_SELF']; ?>" method="post">
    <table width="100%" cellspacing="2" cellpadding="5" class="editform">
	<tr valighn="top">
	<th width="33%" scope="row">Timezone</th>
	<td>
	<select name="iCalTimezone" id="iCalTimezone">
    <?php foreach ($timezones as $timezone) { ?>
    <option value="<?php echo $timezone; ?>"<?php if ($timezone == $iCalTimezone) { echo " selected"; } ?>><?php echo $timezone; ?></option>
    <?php } ?>
    </select>
	</td>
	</tr>
	</table>
	<br />
	<fieldset class="options"><legend>Google Map Options</legend> 
	<table width="100%" cellspacing="2" cellpadding="5" class="editform">
	<tr valign="top"> 
	<th width="33%" scope="row"><a href=""http://www.google.com/apis/maps/>Google Maps API Key</a></th> 
	<td><input name="iCalGoogleMapKey" type="text" id="iCalGoogleMapKey" value="<?php echo $iCalGoogleMapKey; ?>" size="45%" /></td></tr>
		<th width="33%" scope="row">Zoom Level</th> 
	<td><input name="iCalGoogleMapZoom" type="text" id="iCalGoogleMapZoom" value="<?php echo $iCalGoogleMapZoom; ?>" size="4" /></td></tr>
		<th width="33%" scope="row">Width</th> 
	<td><input name="iCalGoogleMapWidth" type="text" id="iCalGoogleMapWidth" value="<?php echo $iCalGoogleMapWidth; ?>" size="4" /></td></tr>
		<th width="33%" scope="row">Height</th> 
	<td><input name="iCalGoogleMapHeight" type="text" id="iCalGoogleMapHeight" value="<?php echo $iCalGoogleMapHeight; ?>" size="4" /></td></tr>
		<!--//<th width="33%" scope="row">Upcoming.org API Key</th> 
	<td><input name="iCalUpcomingKey" type="text" id="iCalUpcomingKey" value="<?php echo $iCalUpcomingKey; ?>" size="45%" /></td></tr>//-->
	</table>
	</fieldset>
		<input type="hidden" name="submitted" value="submitted" />
	<p class="submit"> 
	<input type="submit" name="Submit" value="Update Options &raquo;" /> 
	</p> 
    </form>

    <h2>WP-iCal Functions</h2>
    <p><code>wp_ical_get(post_id, attribute)</code><br />
    Returns a wp-ical related custom field attribute (location, starttime, endtime, geocode, or alldayevent)
    </p>
    <p><code>wp_ical_print_map(post_id)</code><br />
    Displays Google Map
    </p>    
    
</div>   
</body>
</html>
<?php }} ?>